pub trait FetchMultiple<'a, U: ?Sized + Unit<'a>> {
type Output: 'a;
type Actual;
// Required methods
fn get_many(boxed: &'a BlackBox<U>) -> Result<Self::Output, ErrorDesc>;
fn waiting_get_many(
boxed: &'a BlackBox<U>,
) -> Result<Self::Output, ErrorDesc>
where <U as Unit<'a>>::Borrowed: Waitable,
<U as Unit<'a>>::MutBorrowed: Waitable;
}Expand description
An abstraction over Fetch which works over multiple types, and the
six types which have Fetch pre-implemented. This is therefore implemented
for the following types:
&T&mut T&[T]&mut [T]Box<T>Vec<T>(A,)(A, B)(A, B, C)(A, B, C, D)- …
(A, B, C, D, E, F, G, H, I, J, K)
Where each one of the type parameters in the tuple versions must implement
Fetch.
Required Associated Types
Required Methods
fn get_many(boxed: &'a BlackBox<U>) -> Result<Self::Output, ErrorDesc>
fn waiting_get_many(boxed: &'a BlackBox<U>) -> Result<Self::Output, ErrorDesc>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.